==> huaweicloudsdkrds-3.1.98-py2.py3-none-any.whl: huaweicloudsdkrds/v3/model/diagnosis_item_result.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DiagnosisItemResult:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'count': 'int'
    }

    attribute_map = {
        'name': 'name',
        'count': 'count'
    }

    def __init__(self, name=None, count=None):
        """DiagnosisItemResult

        The model defined in huaweicloud sdk

        :param name: 诊断项
        :type name: str
        :param count: 实例数量
        :type count: int
        """
        
        

        self._name = None
        self._count = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if count is not None:
            self.count = count

    @property
    def name(self):
        """Gets the name of this DiagnosisItemResult.

        诊断项

        :return: The name of this DiagnosisItemResult.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DiagnosisItemResult.

        诊断项

        :param name: The name of this DiagnosisItemResult.
        :type name: str
        """
        self._name = name

    @property
    def count(self):
        """Gets the count of this DiagnosisItemResult.

        实例数量

        :return: The count of this DiagnosisItemResult.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """Sets the count of this DiagnosisItemResult.

        实例数量

        :param count: The count of this DiagnosisItemResult.
        :type count: int
        """
        self._count = count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DiagnosisItemResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkrds-3.1.157-py2.py3-none-any.whl: huaweicloudsdkrds/v3/model/diagnosis_item_result.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class DiagnosisItemResult:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'name': 'str',
        'count': 'int'
    }

    attribute_map = {
        'name': 'name',
        'count': 'count'
    }

    def __init__(self, name=None, count=None):
        r"""DiagnosisItemResult

        The model defined in huaweicloud sdk

        :param name: 诊断项
        :type name: str
        :param count: 实例数量
        :type count: int
        """
        
        

        self._name = None
        self._count = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if count is not None:
            self.count = count

    @property
    def name(self):
        r"""Gets the name of this DiagnosisItemResult.

        诊断项

        :return: The name of this DiagnosisItemResult.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        r"""Sets the name of this DiagnosisItemResult.

        诊断项

        :param name: The name of this DiagnosisItemResult.
        :type name: str
        """
        self._name = name

    @property
    def count(self):
        r"""Gets the count of this DiagnosisItemResult.

        实例数量

        :return: The count of this DiagnosisItemResult.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        r"""Sets the count of this DiagnosisItemResult.

        实例数量

        :param count: The count of this DiagnosisItemResult.
        :type count: int
        """
        self._count = count

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, DiagnosisItemResult):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
